==> _private_core_network-1.2.25.tar.gz: lib/network_resources/country/app_api.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';

import 'models/country_available.dart';

class MyAppEndpoint {
  MyAppEndpoint._();
  static String getcountriesAvailableByKeyword() =>
      "v2/country/getcountriesAvailableByKeyword";
  static String getCurrencyOfCountry() => "v2/country/getCurrencyOfCountry";
}

abstract class MyAppApi {
  Future<NetworkResponse> getcountriesAvailableByKeyword(params);
  Future<NetworkResponse> getCurrencyOfCountry(params);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getcountriesAvailableByKeyword(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(requiredToken: false).get(
          MyAppEndpoint.getcountriesAvailableByKeyword(),
          queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => CountryAvailable.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCurrencyOfCountry(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(requiredToken: false)
          .get(MyAppEndpoint.getCurrencyOfCountry(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => CurrencyAvailable.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }
}

==> _private_core_network-1.2.69.tar.gz: lib/network_resources/country/app_api.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';

import 'models/country_available.dart';

class MyAppEndpoint {
  MyAppEndpoint._();
  static String getcountriesAvailableByKeyword() =>
      "v2/country/getcountriesAvailableByKeyword";
  static String getCurrencyOfCountry() => "v2/country/getCurrencyOfCountry";
}

abstract class MyAppApi {
  Future<NetworkResponse> getcountriesAvailableByKeyword(params);
  Future<NetworkResponse> getCurrencyOfCountry(params);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getcountriesAvailableByKeyword(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(requiredToken: false).get(
          MyAppEndpoint.getcountriesAvailableByKeyword(),
          queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => CountryAvailable.fromJson(e)).toList(),
      );
    } on DioException catch (e) {
      appDebugPrint('DioException: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCurrencyOfCountry(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(requiredToken: false)
          .get(MyAppEndpoint.getCurrencyOfCountry(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => CurrencyAvailable.fromJson(json));
    } on DioException catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }
}
